@@ -54,6 +54,17 @@ from fairies.nlp_clean_data import (
 
 
 from navinfo_tool.rule_error_identification1009 import (
-
     error_identification
 )
+
+from navinfo_tool.utils import (
+    read_config,    # 读取配置文件
+    check_and_creat_dir,    # 判断文件目录是否存在，文件目录不存在则创建目录
+    getPolygonArea,    # 计算多边形面积
+    get_bracketed_content,    # 获取文本中所有小括号中的内容组成的list
+    rm_bracketed,    # 去除文本中的括号，包括括号中的内容
+    rm_symbol,    # 去除文本中的所有符号
+    read_csv,    # 读取csv文件
+    write2csv    # 将数组的内容写到csv中
+
+)
\ No newline at end of file
